@@ -34,6 +34,10 @@ class Annotation(Span):
     score: Optional[float] = Field(None, description="Confidence score of the annotation", example=0.87)
     properties: Optional[Dict[str, Any]] = Field(None, description="Properties of annotation")
     terms: Optional[List[Term]] = Field(None, description="Properties of annotation")
+    createdBy: Optional[str] = Field(None, description="Name of the user or the process that created the annotation")
+    createdDate: Optional[str] = Field(None, description="Creation date")
+    modifiedDate: Optional[str] = Field(None, description="Last modification date")
+    status: Optional[str] = Field(None, description="Status of the annotation")
 
 
 class Category(BaseModel):
@@ -41,6 +45,10 @@ class Category(BaseModel):
     label: Optional[str] = Field(None, description="Label of the category", example="ORG")
     score: Optional[float] = Field(None, description="Confidence score of the category", example=0.87)
     properties: Optional[Dict[str, Any]] = Field(None, description="Properties of category")
+    createdBy: Optional[str] = Field(None, description="Name of the user or the process that created the category")
+    createdDate: Optional[str] = Field(None, description="Creation date")
+    modifiedDate: Optional[str] = Field(None, description="Last modification date")
+    status: Optional[str] = Field(None, description="Status of the category")
 
 
 class Sentence(Span):
